package api

import (
	"errors"
	"spu3d/db/repo"
	"time"

	"github.com/gin-gonic/gin"
	"go.mongodb.org/mongo-driver/bson/primitive"
	"infish.cn/comm"
)

// 64d598e3ccc9b7d39470c95a
// const SCOPE = "queenshow"
const SPU3D_SCOPE = "spu3d"

func CreateCategoryRouter(router *GinRouter) {
	router.GETJWT("/spu3d/category", func(c *gin.Context, apictx *ApiSession) (interface{}, error) {
		_, ret := repo.RepoSeachDocMap(apictx.CreateRepoCtx(), &repo.DocSearchOptions{
			CollectName: repo.CollectionCategories,
			Query:       repo.Map{"scope": SPU3D_SCOPE},
		})
		// 没找到数据是创建初始分类
		// if !ok {
		// 	return nil, errors.New("未找到数据！")
		// }
		return ret, nil
	})

	// 创建/更新 spu3d资源分类
	router.POSTJWT("/spu3d/category", func(c *gin.Context, apictx *ApiSession) (interface{}, error) {
		roles, _ := getUserRole(c, apictx)
		// 公共分类 只有管理员能创建该分类
		if !isSysUser(roles) {
			return nil, errors.New("没有权限！")

		}

		body := &comm.DbCategory{}
		err := c.ShouldBindJSON(body)
		if err != nil {
			PrintErr(err, "参数错误")
			return nil, errors.New("参数错误！")
		}
		body.Scope = SPU3D_SCOPE
		body.CreateTime = time.Now()
		if body.Id.IsZero() {
			body.CreateTime = time.Now()
		} else {
			body.UpdateTime = time.Now()
		}

		curr := &comm.DbCategory{}
		ok, err := repo.RepoSeachDoc(apictx.CreateRepoCtx(), &repo.DocSearchOptions{
			CollectName: repo.CollectionCategories,
			Project:     []string{"_id"},
			Query:       repo.Map{"scope": body.Scope},
		}, curr)
		if err != nil {
			return nil, err
		}
		if !ok {
			return repo.RepoAddDoc(apictx.CreateRepoCtx(), repo.CollectionCategories, body)
		}
		if curr.Id.IsZero() {
			return nil, errors.New("id 错误！")
		}

		body.Id = primitive.NilObjectID
		return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionCategories, curr.Id.Hex(), body)
	})

}
